# Mariana Trench

![logo](https://github.com/facebookincubator/mariana-trench/blob/master/logo.png?raw=true)

[![MIT License](https://img.shields.io/badge/license-MIT-blue.svg?style=flat)](http://choosealicense.com/licenses/mit/)

Mariana Trench is a security focused static analysis platform targeting Android.

## License

Mariana Trench is licensed under the MIT license.
